==> v2.7.1.1.tar.gz: gnosygnu_xowa/400_xowa/src/gplx/xowa/specials/xowa/bookmarks/Xows_bmk_page.java <==
/*
XOWA: the XOWA Offline Wiki Application
Copyright (C) 2012 gnosygnu@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package gplx.xowa.specials.xowa.bookmarks; import gplx.*; import gplx.xowa.*; import gplx.xowa.specials.*; import gplx.xowa.specials.xowa.*;
import gplx.core.primitives.*;
import gplx.xowa.users.data.*;
import gplx.xowa.html.xouis.tbls.*;
public class Xows_bmk_page implements Xows_page {
	public Xows_special_meta Special_meta() {return Xows_special_meta_.Itm__bookmarks;}
	public void Special_gen(Xowe_wiki wiki, Xoae_page page, Xoa_url url, Xoa_ttl ttl) {
		Xoud_bmk_mgr bmk_mgr = wiki.App().User().User_db_mgr().Bmk_mgr();
		page.Html_data().Module_mgr().Itm__xoui().Init(wiki.Appe()).Enabled_y_();
		Bry_bfr bfr = wiki.Utl__bfr_mkr().Get_m001();
		Xoud_bmk_row[] rows = bmk_mgr.Get_all();
		Xoui_tbl_itm hui_tbl = Xoui_tbl_itm__bmk.new_(bmk_mgr.Tbl(), rows);
		wiki.Html__xoui_tbl_mgr().Write(bfr, hui_tbl);
		page.Hdump_data().Body_(bfr.To_bry_and_rls());
	}
}

==> v2.7.2.1.tar.gz: gnosygnu_xowa/400_xowa/src/gplx/xowa/specials/xowa/bookmarks/Xows_bmk_page.java <==
/*
XOWA: the XOWA Offline Wiki Application
Copyright (C) 2012 gnosygnu@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package gplx.xowa.specials.xowa.bookmarks; import gplx.*; import gplx.xowa.*; import gplx.xowa.specials.*; import gplx.xowa.specials.xowa.*;
import gplx.core.primitives.*;
import gplx.xowa.html.xouis.tbls.*;
import gplx.xowa.users.data.*; import gplx.xowa.users.bmks.*;
public class Xows_bmk_page implements Xows_page {
	public Xows_special_meta Special_meta() {return Xows_special_meta_.Itm__bookmarks;}
	public void Special_gen(Xowe_wiki wiki, Xoae_page page, Xoa_url url, Xoa_ttl ttl) {
		Xoud_bmk_mgr bmk_mgr = wiki.App().User().User_db_mgr().Bmk_mgr();
		page.Html_data().Module_mgr().Itm__xoui().Init(wiki.Appe()).Enabled_y_();
		Bry_bfr bfr = wiki.Utl__bfr_mkr().Get_m001();
		Xoud_bmk_itm_row[] rows = bmk_mgr.Itms__get(Xoud_bmk_mgr.Owner_root);
		Xoui_tbl_itm hui_tbl = Xoui_tbl_itm__bmk.new_(bmk_mgr.Tbl__itm(), rows);
		wiki.Html__xoui_tbl_mgr().Write(bfr, hui_tbl);
		page.Hdump_data().Body_(bfr.To_bry_and_rls());
	}
}
